[U-Boot] [PATCH 3/8] rockchip: rk3188: Cleanup some SPL/TPL rename leftovers

Heiko Stuebner heiko at sntech.de
Mon Mar 20 11:40:31 UTC 2017


In the beginning, we did SPL -> TPL -> U-Boot, but after clarification
of the real ordering swapped SPL and TPL.
It seems some renames were forgotten and may confuse future readers, so
also swap these to reflect the actual ordering.

Signed-off-by: Heiko Stuebner <heiko at sntech.de>
---
 arch/arm/mach-rockchip/rk3188-board-tpl.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/arch/arm/mach-rockchip/rk3188-board-tpl.c b/arch/arm/mach-rockchip/rk3188-board-tpl.c
index 442bfe7aa7..b458ef6ea8 100644
--- a/arch/arm/mach-rockchip/rk3188-board-tpl.c
+++ b/arch/arm/mach-rockchip/rk3188-board-tpl.c
@@ -17,7 +17,7 @@ DECLARE_GLOBAL_DATA_PTR;
 static int rk3188_num_entries __attribute__ ((section(".data")));
 
 #define PMU_BASE	0x20004000
-#define TPL_ENTRY	0x10080C00
+#define SPL_ENTRY	0x10080C00
 
 static void jump_to_spl(void)
 {
@@ -25,9 +25,9 @@ static void jump_to_spl(void)
 
 	struct rk3188_pmu * const pmu = (void *)PMU_BASE;
 	image_entry_noargs_t tpl_entry =
-		(image_entry_noargs_t)(unsigned long)TPL_ENTRY;
+		(image_entry_noargs_t)(unsigned long)SPL_ENTRY;
 
 	/* Store the SAVE_SP_ADDR in a location shared with TPL. */
 	writel(SAVE_SP_ADDR, &pmu->sys_reg[2]);
 	tpl_entry();
 }
@@ -25,9 +25,9 @@ static void jump_to_spl(void)
 
-	/* Store the SAVE_SP_ADDR in a location shared with TPL. */
+	/* Store the SAVE_SP_ADDR in a location shared with SPL. */
 	writel(SAVE_SP_ADDR, &pmu->sys_reg[2]);
 	tpl_entry();
-- 
2.11.0



More information about the U-Boot mailing list